==> pgpp-0.2.2.tar.gz: pgpp-0.2.2/README.md <==
# Pg++

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by RedRyan from RedProductions

## Examples of How To Use

Basic Window

```python
from pypp import *

WIDTH, HEIGHT = 1080, 720 # define the dimensions

WHITE = (255, 255, 255) # define color white in rgb values

createWindow("Py++", WIDTH, HEIGHT, "logo.png") # crezate a window

def main():
    clock() # start a framerate cap
    run = True
    
    while run:
        clockTick(30) # cap the frame rate at 30 fps
        for event in getEvents(): # get window events
            if event.type == eventQuit(): # quit the window
                run = False

        setBackground(WHITE) # set the window background
        drawWindow() # update all the elements inside the window
    
    gameQuit() # quit if main loop broken

main()


```

Creating A Moving Sprite
```python
from pypp import * # import py++

WIDTH, HEIGHT = 1080, 720 # define the dimensions

WHITE = (255, 255, 255) # define color white in rgb values

createWindow("Py++", WIDTH, HEIGHT, "logo.png") # create a window

setSprite("player", "spaceship.png", 100, 360, 100, 100, 150, 150, 0, [1, 3]) # create a sprite

def main():
    clock() # start a framerate cap
    run = True
    
    while run:
        clockTick(30) # cap the frame rate at 30 fps
        for event in getEvents(): # get window events
            if event.type == eventQuit(): # quit the window
                run = False

        keys = getKeyPressed() # get all the keys pressed
        
        if keys[keyW()]: # if key w pressed move upwards
            tryMoveY("player", -6)
        if keys[keyS()]: # if key s pressed move downwards
            tryMoveY("player", 6)
        if keys[keyA()]: # if key a pressed move to the left
            tryMoveX("player", -6)
        if keys[keyD()]: # if key d pressed move to the right
            tryMoveX("player", 6)
        
        setBackground(WHITE) # set the window background
        drawWindow() # update all the elements inside the window
    
    gameQuit() # quit if main loop broken

main()

```

==> pgpp-1.1.1.tar.gz: pgpp-1.1.1/README.md <==
# Pg++

Rewrite! Stable with some bugs

Developed by RedRyan from RedProductions

## Installation
```python
pip install pgpp
```

## Examples of How To Use

Basic Window

```python
from pgpp import *

WIDTH, HEIGHT = 1080, 720 # define the dimensions

WHITE = (255, 255, 255) # define color white in rgb values

createWindow("Pg++", WIDTH, HEIGHT) # crezate a window
setBackground(WHITE) # set the window background

def main():
    startClock() # start a framerate cap
    run = 1

    while run:
        clockTick(30) # cap the frame rate at 30 fps
        for event in getEvents(): # get window events
            if event.type == eventQuit(): # quit the window
                run = False

        drawWindow() # update all the elements inside the window

    gameQuit() # quit if main loop broken

if __name__ == "__main__":
    main()

```

Creating A Moving Sprite
```python
from pgpp import * # import py++

WIDTH, HEIGHT = 1080, 720 # define the dimensions

WHITE = (255, 255, 255) # define color white in rgb values

createWindow("Pg++", WIDTH, HEIGHT) # create a window

setBackground(WHITE) # set the window background


setElement("player", "spaceship.png", 100, 100, 100, 100, 100, 0, [False, False], [1], 1) # create a sprite

def main():
    startClock() # start a framerate cap
    run = True

    while run:
        clockTick(30) # cap the frame rate at 30 fps
        for event in getEvents(): # get window events
            if event.type == eventQuit(): # quit the window
                run = False

        keys = getKeyPressed() # get all the keys pressed

        if keys[keyW()]: # if key w pressed move upwards
            tryMoveY("player", -6)
        if keys[keyS()]: # if key s pressed move downwards
            tryMoveY("player", 6)
        if keys[keyA()]: # if key a pressed move to the left
            tryMoveX("player", -6)
        if keys[keyD()]: # if key d pressed move to the right
            tryMoveX("player", 6)

        drawWindow() # update all the elements inside the window

    gameQuit() # quit if main loop broken

if __name__ == "__main__":
    main()

```
